init_all

Function init_all 

pub fn init_all() -> Vec<(String, Box<dyn BusDriver>)>
Initialise all known bus drivers and return the ones that succeeded.

Call this once at startup, then pass the result to BusSchemeServer::new().